@@ -230,6 +230,7 @@ func (t *Template) Apply(s string) (string, error) {
 			"reverseFilter":  filter(true),
 			"mdv2escape":     mdv2Escape,
 			"envOrDefault":   t.envOrDefault,
+			"isEnvSet":       t.isEnvSet,
 			"map":            makemap,
 			"indexOrDefault": indexOrDefault,
 		}).
@@ -256,6 +257,11 @@ func (t *Template) ApplyAll(sps ...*string) error {
 	return nil
 }
 
+func (t *Template) isEnvSet(name string) bool {
+	s, ok := t.fields[env].(context.Env)[name]
+	return ok && s != ""
+}
+
 func (t *Template) envOrDefault(name, value string) string {
 	s, ok := t.fields[env].(context.Env)[name]
 	if !ok {
@@ -337,27 +343,29 @@ func filter(reverse bool) func(content, exp string) string {
 	}
 }
 
+var mdv2EscapeReplacer = strings.NewReplacer(
+	"_", "\\_",
+	"*", "\\*",
+	"[", "\\[",
+	"]", "\\]",
+	"(", "\\(",
+	")", "\\)",
+	"~", "\\~",
+	"`", "\\`",
+	">", "\\>",
+	"#", "\\#",
+	"+", "\\+",
+	"-", "\\-",
+	"=", "\\=",
+	"|", "\\|",
+	"{", "\\{",
+	"}", "\\}",
+	".", "\\.",
+	"!", "\\!",
+)
+
 func mdv2Escape(s string) string {
-	return strings.NewReplacer(
-		"_", "\\_",
-		"*", "\\*",
-		"[", "\\[",
-		"]", "\\]",
-		"(", "\\(",
-		")", "\\)",
-		"~", "\\~",
-		"`", "\\`",
-		">", "\\>",
-		"#", "\\#",
-		"+", "\\+",
-		"-", "\\-",
-		"=", "\\=",
-		"|", "\\|",
-		"{", "\\{",
-		"}", "\\}",
-		".", "\\.",
-		"!", "\\!",
-	).Replace(s)
+	return mdv2EscapeReplacer.Replace(s)
 }
 
 func makemap(kvs ...string) (map[string]string, error) {
