@@ -18,9 +18,9 @@ func TestTarGzFile(t *testing.T) {
 	tmp := t.TempDir()
 	f, err := os.Create(filepath.Join(tmp, "test.tar.gz"))
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 	archive := New(f)
-	defer archive.Close() // nolint: errcheck
+	defer archive.Close()
 
 	require.Error(t, archive.Add(config.File{
 		Source:      "../testdata/nope.txt",
@@ -68,7 +68,7 @@ func TestTarGzFile(t *testing.T) {
 
 	f, err = os.Open(f.Name())
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 
 	info, err := f.Stat()
 	require.NoError(t, err)
@@ -76,7 +76,7 @@ func TestTarGzFile(t *testing.T) {
 
 	gzf, err := gzip.NewReader(f)
 	require.NoError(t, err)
-	defer gzf.Close() // nolint: errcheck
+	defer gzf.Close()
 
 	var paths []string
 	r := tar.NewReader(gzf)
@@ -111,9 +111,9 @@ func TestTarGzFileInfo(t *testing.T) {
 	now := time.Now().Truncate(time.Second)
 	f, err := os.Create(filepath.Join(t.TempDir(), "test.tar.gz"))
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 	archive := New(f)
-	defer archive.Close() // nolint: errcheck
+	defer archive.Close()
 
 	require.NoError(t, archive.Add(config.File{
 		Source:      "../testdata/foo.txt",
@@ -131,11 +131,11 @@ func TestTarGzFileInfo(t *testing.T) {
 
 	f, err = os.Open(f.Name())
 	require.NoError(t, err)
-	defer f.Close() // nolint: errcheck
+	defer f.Close()
 
 	gzf, err := gzip.NewReader(f)
 	require.NoError(t, err)
-	defer gzf.Close() // nolint: errcheck
+	defer gzf.Close()
 
 	var found int
 	r := tar.NewReader(gzf)
